/**
 * Source: https://github.com/madrobby/keymaster/blob/3b1f2afabf1569848dea8b697ac418f19b601a30/keymaster.js
 */
export declare const KEY_MAP: {
    [code: string]: number;
};
/**
 * Valid modifier keys.
 */
export declare const MODIFIERS: number[];
/**
 * Continue propagating the event to older listeners.
 */
export declare const SHOULD_PROPAGATE: boolean;
/**
 * Stringify a keyboard event.
 */
export declare function keyboardEventCombo(e: KeyboardEvent): string;
/**
 * Map keys to string.
 */
export declare function stringifyKey(...keys: (string | number)[]): string;
/**
 * Event handlers.
 */
export declare type EventHandler = (e: KeyboardEvent) => void;
export declare type ListenerHandler = (combo: string, e: KeyboardEvent) => void | boolean;
/**
 * Keyboard shortcut map.
 */
export interface Shortcuts {
    [key: string]: EventHandler;
}
/**
 * Create a listener function from shortcuts.
 */
export declare function createShortcuts(shortcuts: Shortcuts, returnValue?: boolean): ListenerHandler;
/**
 * Keyboard manager library for mapping key events.
 */
export declare class Keyboard {
    listeners: ListenerHandler[];
    addListener(callback: ListenerHandler): number;
    removeListener(callback: ListenerHandler): number;
    getHandler(): (event: KeyboardEvent) => boolean | void;
    getListener(returnValue?: boolean): ListenerHandler;
}
